%define common_summary interact with virtualization capabilities
%define common_description Libvirt is a C toolkit to interact with the virtualization\
capabilities of recent versions of Linux.
%define lib_major 0

%define lib_name %mklibname virt %{lib_major}
%define develname %mklibname -d virt
%define staticdevelname %mklibname -d -s virt

# libxenstore is not versionned properly
%define _requires_exceptions devel(libxenstore.*)

Name:		libvirt
Version:	0.4.0
Release:	%mkrel 3
Summary:	Toolkit to %{common_summary}
License:	LGPLv2+
Group:		System/Kernel and hardware
Url:		http://libvirt.org/
Source0		ftp://libvirt.org/libvirt/libvirt-%{version}.tar.gz
# XXX: for %%{_sysconfdir}/sasl2
Requires:	cyrus-sasl
BuildRequires:	xen-devel >= 3.0.4
BuildRequires:	libxml2-devel
BuildRequires:	ncurses-devel
BuildRequires:	readline-devel
BuildRequires:	python-devel
BuildRequires:	gnutls-devel
BuildRequires:  libsasl-devel

%description
%{common_description}

Virtualization of the Linux Operating System means the
ability to run multiple instances of Operating Systems concurently on
a single hardware system where the basic resources are driven by a
Linux instance. The library aim at providing long term stable C API
initially for the Xen paravirtualization but should be able to
integrate other virtualization mechanisms if needed.

%package -n	%{lib_name}
Summary:	A library to %{common_summary}
Group:		System/Libraries

%description -n	%{lib_name}
%{common_description}

This package contains the library needed to run programs dynamically
linked with %{name}.

%package -n	%{develname}
Summary:	Development tools for programs using %{name}
Group:		Development/C
Requires:	%{lib_name} = %{version}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{lib_name}-devel

%description -n	%{develname}
%{common_description}

This package contains the header files and libraries needed for
developing programs using the %{name} library.

%package -n	%{staticdevelname}
Summary:	Development static libraries for programs using %{name}
Group:		Development/C
Provides:	%{name}-static-devel = %{version}-%{release}
Obsoletes:	%{lib_name}-static-devel

%description -n	%{staticdevelname}
%{common_description}

This package contains the static libraries needed for developing
programs using the %{name} library.

%package -n	python-%{name}
Summary:	Python bindings to %{common_summary}
Group:		Development/Python

%description -n	python-%{name}
%{common_description}

This package contains the python bindings for the %{name} library.

%package -n	%{name}-utils
Summary:	Tools to %{common_summary}
Group:		System/Kernel and hardware

%description -n	%{name}-utils
%{common_description}

This package contains tools for the %{name} library.

%prep
%setup -q

%build
%configure2_5x --localstatedir=%{_var} --with-html-subdir=%{name}
%make

%install
rm -rf %{buildroot}
%makeinstall
install -d -m 755 %{buildroot}%{_var}/run/%{name}
%find_lang %{name}

# fix documentation
mv %{buildroot}%{_docdir}/%{name}-python-%{version} %{buildroot}%{_docdir}/python-%{name}
install -m 644 ChangeLog README TODO NEWS %{buildroot}%{_docdir}/%{name}

%clean
rm -rf %{buildroot}

%post -n %{lib_name} -p /sbin/ldconfig
%postun -n %{lib_name} -p /sbin/ldconfig

%files -n %{lib_name} -f %{name}.lang
%defattr(-,root,root)
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/ChangeLog
%{_docdir}/%{name}/README
%{_docdir}/%{name}/TODO
%{_docdir}/%{name}/NEWS
%{_libdir}/%{name}.so.%{lib_major}*
%{_libdir}/%{name}_proxy

%files -n %{develname}
%defattr(-,root,root)
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/ChangeLog
%exclude %{_docdir}/%{name}/README
%exclude %{_docdir}/%{name}/TODO
%exclude %{_docdir}/%{name}/NEWS
%doc %{_datadir}/gtk-doc/html/%{name}
%{_includedir}/%{name}
%{_libdir}/%{name}.so
%{_libdir}/%{name}.la
%{_libdir}/pkgconfig/%{name}.pc

%files -n %{staticdevelname}
%defattr(-,root,root)
%{_libdir}/%{name}.a

%files -n python-%{name}
%defattr(-,root,root)
%doc %{_docdir}/python-%{name}
%{py_platsitedir}/%{name}.py
%{py_platsitedir}/%{name}mod.a
%{py_platsitedir}/%{name}mod.la
%{py_platsitedir}/%{name}mod.so

%files -n %{name}-utils
%defattr(-,root,root)
%{_bindir}/*
%{_mandir}/man1/virsh.1*
%{_sbindir}/*
%{_initrddir}/libvirtd
%{_sysconfdir}/sysconfig/libvirtd
%{_var}/run/libvirt
%config(noreplace) %{_sysconfdir}/libvirt
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf


%changelog
* Mon Jan 21 2008 Funda Wang <fundawang@mandriva.org> 0.4.0-3mdv2008.1
+ Revision: 155530
- rebuild

* Tue Dec 18 2007 David Walluck <walluck@mandriva.org> 0.4.0-2mdv2008.1
+ Revision: 132143
- BuildRequires: libsasl-devel
- 0.4.0

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 07 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.3.3-1mdv2008.1
+ Revision: 116159
- new version

* Sat Sep 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.3.2-2mdv2008.0
+ Revision: 92284
- new doc policy
- ship %%{_var}/run/libvirt directory for libvirtd
- fix nasty redefinition of standard GNU directory localstatedir by %%configure macro...

* Thu Aug 30 2007 Funda Wang <fundawang@mandriva.org> 0.3.2-1mdv2008.0
+ Revision: 75151
- New version 0.3.2

* Thu Jul 12 2007 Funda Wang <fundawang@mandriva.org> 0.3.0-1mdv2008.0
+ Revision: 51565
- fix file list
- New version

* Tue Jun 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.2.3-1mdv2008.0
+ Revision: 41371
- new version

* Sat Jun 02 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.2.2-1mdv2008.0
+ Revision: 34672
- new version


* Fri Feb 23 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.2.0-1mdv2007.0
+ Revision: 125026
- fix build dependencies
- new version
- new version

* Wed Jan 17 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.1.10-1mdv2007.1
+ Revision: 109906
- minor spec cleanup
- new version

* Wed Dec 13 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0.1.9-1mdv2007.1
+ Revision: 96226
- new version
- rebuild for latest python

* Mon Oct 16 2006 Olivier Blin <oblin@mandriva.com> 0.1.7-3mdv2006.0
+ Revision: 65351
- remove libxenstore devel requires on x86_64 as well

* Sun Oct 15 2006 Olivier Blin <oblin@mandriva.com> 0.1.7-2mdv2007.1
+ Revision: 65070
- don't require devel(libxenstore), it is not versionned properly

* Sat Oct 14 2006 Olivier Blin <oblin@mandriva.com> 0.1.7-1mdv2006.0
+ Revision: 64654
- buildrequires python-devel
- buildrequires readline-devel
- buildrequires ncurses-devel
- buildrequires libxml2-devel
- buildrequires libxml-devel
- initial libvirt release
- Create libvirt

